@@ -38,13 +38,13 @@ emacspeak modules:
 
 """
 
-__id__ = "$Id: espeechfactory.py 2234 2007-04-02 18:36:08Z wwalker $"
+__id__ = "$Id: espeechfactory.py 3287 2007-11-29 21:46:14Z richb $"
 __author__ = "T. V. Raman"
-__version__ = "$Revision: 2234 $"
-__date__ = "$Date: 2007-04-02 14:36:08 -0400 (Mon, 02 Apr 2007) $"
+__version__ = "$Revision: 3287 $"
+__date__ = "$Date: 2007-11-29 16:46:14 -0500 (Thu, 29 Nov 2007) $"
 __copyright__ = "Copyright (c) 2005 Google Inc."
 __license__ = "LGPL"
-__all__=['Speaker']
+__all__ = ['Speaker']
 
 import os
 
@@ -73,7 +73,7 @@ class SpeechServer(speechserver.SpeechServer):
 
     """
 
-    location="/usr/share/emacs/site-lisp/emacspeak/servers"
+    location = "/usr/share/emacs/site-lisp/emacspeak/servers"
 
     config = {'splitcaps' : 1,
               'rate' : 70,
@@ -115,7 +115,8 @@ class SpeechServer(speechserver.SpeechServer):
 
         f = open(os.path.join(SpeechServer.location, '.servers'))
         for line in f:
-            if line[0] == '#' or line.strip() == '': continue
+            if line[0] == '#' or line.strip() == '':
+                continue
             name = line.strip()
             if not SpeechServer.__activeServers.has_key(name):
                 try:
@@ -128,7 +129,7 @@ class SpeechServer(speechserver.SpeechServer):
 
     getSpeechServers = staticmethod(getSpeechServers)
 
-    def getSpeechServer(info=['outloud','outloud']):
+    def getSpeechServer(info=['outloud', 'outloud']):
         """Gets a given SpeechServer based upon the info.
         See SpeechServer.getInfo() for more info.
         """
@@ -177,18 +178,19 @@ class SpeechServer(speechserver.SpeechServer):
         #print "Command = ", cmd
         #self._output = os.popen(cmd, "w", 1)
         [self._output, stdout, stderr] = os.popen3(cmd, "w", 1)
-        self._settings ={}
+        self._settings = {}
         if initial:
             self._settings.update(initial)
             self.configure(self._settings)
 
-    def configure(self, settings):
+    def configure(self, engineSettings):
         """Configure engine with settings."""
-        for k in settings.keys():
-            if hasattr(self, k) and callable(getattr(self,k)):
-                getattr(self,k)(settings[k])
+        for k in engineSettings.keys():
+            if hasattr(self, k) and callable(getattr(self, k)):
+                getattr(self, k)(engineSettings[k])
 
-    def settings(self): return self._settings
+    def settings(self):
+        return self._settings
 
     def getInfo(self):
         """Returns [driverName, serverId]
@@ -209,7 +211,6 @@ class SpeechServer(speechserver.SpeechServer):
                 families.append(speechserver.VoiceFamily(props))
         except:
             debug.printException(debug.LEVEL_SEVERE)
-            pass
 
         return families
 
@@ -217,7 +218,7 @@ class SpeechServer(speechserver.SpeechServer):
         """Queue text to be spoken.
         Output is produced by next call to say() or speak()."""
         if acss:
-            code =self.getvoice(acss)
+            code = self.getvoice(acss)
             self._output.write("q {%s %s %s}\n" %(code[0], text,
         code[1]))
         else:
@@ -235,14 +236,15 @@ class SpeechServer(speechserver.SpeechServer):
         """Speak single character."""
         self._output.write("l {%s}\n" % character)
 
-    def speakUtterances(self, list, acss=None, interrupt=True):
+    def speakUtterances(self, utteranceList, acss=None, interrupt=True):
         """Speak list of utterances."""
         if acss:
-            code =self.getvoice(acss)
-            for t in list:
-                self._output.write("q { %s %s %s }\n" %(code[0], str(t), code[1]))
+            code = self.getvoice(acss)
+            for t in utteranceList:
+                self._output.write("q { %s %s %s }\n" % \
+                                   (code[0], str(t), code[1]))
         else:
-            for t in list:
+            for t in utteranceList:
                 self._output.write("q { %s }\n" % str(t))
         self._output.write("d\n")
 
@@ -255,7 +257,7 @@ class SpeechServer(speechserver.SpeechServer):
             return
 
         if acss:
-            code =self.getvoice(acss)
+            code = self.getvoice(acss)
             self._output.write("q {%s %s %s}\nd\n" %(code[0], text, code[1]))
         else:
             self._output.write("q {%s}\nd\n" %text)
@@ -351,14 +353,14 @@ def _test():
     """Self test."""
     import time
     import acss
-    s=SpeechServer()
-    a=acss.ACSS()
+    s = SpeechServer()
+    a = acss.ACSS()
     s.punctuations('some')
-    s.queueText("This is an initial test.");
+    s.queueText("This is an initial test.")
     s.queueText("Next, we'll test audio formatted output.")
     for d in ['average-pitch', 'pitch-range',
               'richness', 'stress']:
-        for i in range(0,10,2):
+        for i in range(0, 10, 2):
             a[d] = i
             s.queueText("Set %s to %i. " % (d, i), a)
         del a[d]
@@ -369,4 +371,5 @@ def _test():
     s.shutdown()
 
 
-if __name__=="__main__": _test()
+if __name__ == "__main__":
+    _test()
