@@ -19,9 +19,9 @@
 
 """Provides the default implementation for flat review for Orca."""
 
-__id__        = "$Id: flat_review.py 3313 2007-11-30 21:23:49Z richb $"
-__version__   = "$Revision: 3313 $"
-__date__      = "$Date: 2007-11-30 16:23:49 -0500 (Fri, 30 Nov 2007) $"
+__id__        = "$Id: flat_review.py 3461 2008-01-14 23:04:16Z richb $"
+__version__   = "$Revision: 3461 $"
+__date__      = "$Date: 2008-01-14 18:04:16 -0500 (Mon, 14 Jan 2008) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -119,7 +119,18 @@ class Word:
         if attr == "chars":
             if isinstance(self.zone, TextZone):
                 text = self.zone.accessible.queryText()
+
+                # Pylint is confused and flags this warning:
+                #
+                # W0201:132:Word.__getattr__: Attribute 'chars' defined 
+                # outside __init__
+                #
+                # So for now, we just disable this error in this method.
+                #
+                # pylint: disable-msg=W0201
+
                 self.chars = []
+
                 i = 0
                 while i < self.length:
                     [char, startOffset, endOffset] = text.getTextAtOffset(
@@ -179,7 +190,18 @@ class Zone:
         """
 
         if attr == "words":
+
+            # Pylint is confused and flags this warning:
+            #
+            # W0201:203:Zone.__getattr__: Attribute 'words' defined 
+            # outside __init__
+            #
+            # So for now, we just disable this error in this method.
+            #
+            # pylint: disable-msg=W0201
+
             self.words = []
+
             return self.words
         elif attr.startswith('__') and attr.endswith('__'):
             raise AttributeError, attr
@@ -253,7 +275,18 @@ class TextZone(Zone):
 
         if attr == "words":
             text = self.accessible.queryText()
+
+            # Pylint is confused and flags this warning:
+            #
+            # W0201:288:TextZone.__getattr__: Attribute 'words' defined
+            # outside __init__
+            #
+            # So for now, we just disable this error in this method.
+            #
+            # pylint: disable-msg=W0201
+
             self.words = []
+
             wordIndex = 0
             offset = self.startOffset
             for string in whitespace_re.split(self.string):
@@ -1290,6 +1323,15 @@ class Context:
            or (rootrole == pyatspi.ROLE_SCROLL_BAR):
             return self.getZonesFromAccessible(root, rootexts)
 
+        # If this is a status bar, only pursue its children if we cannot
+        # get non-empty text information from the status bar.
+        # See bug #506874 for more details.
+        #
+        if rootrole == pyatspi.ROLE_STATUS_BAR:
+            zones = self.getZonesFromText(root, rootexts)
+            if len(zones):
+                return zones
+
         # Otherwise, dig deeper.
         #
         # We'll include page tabs: while they are parents, their extents do
