@@ -21,9 +21,9 @@
 something that self-voicing applications can use as their speech
 service."""
 
-__id__        = "$Id: httpserver.py 3274 2007-11-29 18:19:59Z wwalker $"
-__version__   = "$Revision: 3274 $"
-__date__      = "$Date: 2007-11-29 13:19:59 -0500 (Thu, 29 Nov 2007) $"
+__id__        = "$Id: httpserver.py 3445 2008-01-11 17:05:52Z wwalker $"
+__version__   = "$Revision: 3445 $"
+__date__      = "$Date: 2008-01-11 12:05:52 -0500 (Fri, 11 Jan 2008) $"
 __copyright__ = "Copyright (c) 2006-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -92,7 +92,7 @@ class _HTTPRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
                 self.send_header("Content-type", "text/html")
                 self.end_headers()
                 self.wfile.write("%s" % speech.isSpeaking())
-            elif inputBody.startswith("log:"):
+            elif settings.enableRemoteLogging and inputBody.startswith("log:"):
                 import logging
                 logFile = inputBody[4:]
                 for logger in ['braille', 'speech']:
@@ -111,7 +111,7 @@ class _HTTPRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
                         log.addHandler(loggingFileHandlers[logger])
                     log.setLevel(logging.INFO)
                 self.send_response(200, 'OK')
-            elif inputBody == "recordStart":
+            elif settings.enableRemoteLogging and inputBody == "recordStart":
                 import logging
                 import StringIO
                 for logger in ['braille', 'speech']:
@@ -131,7 +131,7 @@ class _HTTPRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
                     loggingStreamHandlers[logger] = [stringIO, handler]
                     log.setLevel(logging.INFO)
                 self.send_response(200, 'OK')
-            elif inputBody == "recordStop":
+            elif settings.enableRemoteLogging and inputBody == "recordStop":
                 import logging
                 import StringIO
                 result = ''
