@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2006 Sun Microsystems Inc.
+# Copyright 2004-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -33,10 +33,10 @@ created in their own module.  The module defining the Script subclass
 is also required to have a 'getScript(app)' method that returns an
 instance of the Script subclass.  See default.py for an example."""
 
-__id__        = "$Id: script.py 2437 2007-05-31 12:41:26Z wwalker $"
-__version__   = "$Revision: 2437 $"
-__date__      = "$Date: 2007-05-31 08:41:26 -0400 (Thu, 31 May 2007) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: script.py 3496 2008-01-24 17:40:12Z richb $"
+__version__   = "$Revision: 3496 $"
+__date__      = "$Date: 2008-01-24 12:40:12 -0500 (Thu, 24 Jan 2008) $"
+__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import braillegenerator
@@ -47,6 +47,7 @@ import orca_state
 import settings
 import speechgenerator
 import where_am_I
+import bookmarks
 
 class Script:
     """The specific focus tracking scripts for applications.
@@ -60,7 +61,6 @@ class Script:
         Arguments:
         - app: the Python Accessible application to create a script for
         """
-
         self.app = app
 
         if app:
@@ -69,7 +69,7 @@ class Script:
             self.name = "default"
 
         self.name += " (module=" + self.__module__ + ")"
-
+        
         self.listeners = self.getListeners()
 
         # By default, handle events for non-active applications.
@@ -77,13 +77,16 @@ class Script:
         self.presentIfInactive = True
 
         self.inputEventHandlers = {}
+        self.pointOfReference = {}
         self.setupInputEventHandlers()
         self.keyBindings = self.getKeyBindings()
         self.brailleBindings = self.getBrailleBindings()
+        self.app_pronunciation_dict = self.getPronunciations()
 
         self.brailleGenerator = self.getBrailleGenerator()
         self.speechGenerator = self.getSpeechGenerator()
         self.whereAmI = self.getWhereAmI()
+        self.bookmarks = self.getBookmarks()
         self.voices = settings.voices
 
         self.flatReviewContextClass = flat_review.Context
@@ -96,8 +99,8 @@ class Script:
         # giving up on an object.  This might need to be overridden by the
         # script.  See bug #397787.
         #
-        self.commFailureWaitTime = 0.1
-        self.commFailureAttemptLimit = 5
+        self.commFailureWaitTime = settings.commFailureWaitTime
+        self.commFailureAttemptLimit = settings.commFailureAttemptLimit
 
         debug.println(debug.LEVEL_FINE, "NEW SCRIPT: %s" % self.name)
 
@@ -148,6 +151,15 @@ class Script:
         """
         return {}
 
+    def getPronunciations(self):
+        """Defines the application specific pronunciations for this script.
+
+        Returns a dictionary where the keys are the actual text strings and
+        the values are the replacement strings that are spoken instead.
+        """
+
+        return {}
+
     def getBrailleCommandsForInputHandler(self, inputEventHandler):
         """Returns a list of BrlTTY commands (they're in braille.py) that
         match the given inputEventHandler passed as argument.
@@ -176,6 +188,30 @@ class Script:
         """Returns the "where am I" class for this script.
         """
         return where_am_I.WhereAmI(self)
+    
+    def echoKey(self, keyEvent):
+        """Determine whether this script should echo the current key event.
+        Note that the keyEcho() method in orca.py will still take into 
+        account whatever the user's various preferences for key echoing
+        are, which may override what is return by this echoKey() method.
+
+        Arguments:
+        - keyEvent - the key event
+
+        Returns an indication of whether a key echo event should be
+        allowed to happen for this script.
+        """
+
+        return True
+
+    def getBookmarks(self):
+        """Returns the "bookmarks" class for this script.
+        """
+        try:
+            return self.bookmarks 
+        except AttributeError:
+            self.bookmarks = bookmarks.Bookmarks(self)
+            return self.bookmarks
 
     def getAppPreferencesGUI(self):
         """Return a GtkVBox contain the application unique configuration
@@ -202,6 +238,30 @@ class Script:
 
         return keyBindings
 
+    def overridePronunciations(self, script, pronunciations):
+        """Allow for the customization of application specific pronunciations.
+
+        Arguments:
+        - script: the application script.
+        - pronunciations: the dictionary of pronunciations for this script.
+        """
+
+        return pronunciations
+
+    def getAppState(self):
+        """Returns an object that can be passed to setAppState.  This
+        object will be used by setAppState to restore any state
+        information that was being maintained by the script."""
+        return None
+
+    def setAppState(self, appState):
+        """Sets the application state using the given appState object.
+
+        Arguments:
+        - appState: an object obtained from getAppState
+        """
+        return
+        
     # [[[WDW - There is a circular reference going on somewhere (see
     # bug 333168).  In the presence of this reference, the existence
     # of a __del__ method prevents the garbage collector from
