@@ -19,9 +19,9 @@
 
 """Custom script for gedit."""
 
-__id__        = "$Id: gedit.py 3280 2007-11-29 19:55:36Z wwalker $"
-__version__   = "$Revision: 3280 $"
-__date__      = "$Date: 2007-11-29 14:55:36 -0500 (Thu, 29 Nov 2007) $"
+__id__        = "$Id: gedit.py 3354 2007-12-08 02:40:44Z eitani $"
+__version__   = "$Revision: 3354 $"
+__date__      = "$Date: 2007-12-07 21:40:44 -0500 (Fri, 07 Dec 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -110,6 +110,16 @@ class Script(default.Script):
         """
         return SpeechGenerator(self)
 
+    def getListeners(self):
+        """Sets up the AT-SPI event listeners for this script.
+        """
+        listeners = default.Script.getListeners(self)
+
+        listeners["object:state-changed:focused"]           = \
+            self.onStateChanged
+
+        return listeners
+
     def __sayAllProgressCallback(self, context, progressType):
         """Provide feedback during the sayAll operation.
         """
