@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 3278 2007-11-29 19:07:04Z shaeger $"
-__version__   = "$Revision: 3278 $"
-__date__      = "$Date: 2007-11-29 14:07:04 -0500 (Thu, 29 Nov 2007) $"
+__id__        = "$Id: settings.py 3495 2008-01-24 16:53:04Z shaeger $"
+__version__   = "$Revision: 3495 $"
+__date__      = "$Date: 2008-01-24 11:53:04 -0500 (Thu, 24 Jan 2008) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -107,6 +107,7 @@ userCustomizableSettings = [
     "brailleSelectorIndicator",
     "enableBrailleMonitor",
     "enableMagnifier",
+    "enableMagLiveUpdating",
     "enableMagCursor",
     "enableMagCursorExplicitSize",
     "magCursorSize",
@@ -114,14 +115,33 @@ userCustomizableSettings = [
     "enableMagCrossHair",
     "enableMagCrossHairClip",
     "magCrossHairSize",
+    "magCrossHairColor",
+    "magZoomerType",
     "magZoomerLeft",
     "magZoomerRight",
     "magZoomerTop",
     "magZoomerBottom",
     "magZoomFactor",
+    "enableMagZoomerBorder",
+    "magZoomerBorderSize",
+    "magZoomerBorderColor",
     "enableMagZoomerColorInversion",
+    "magBrightnessLevel",
+    "magBrightnessLevelRed",
+    "magBrightnessLevelBlue",
+    "magBrightnessLevelGreen",
+    "magContrastLevel",
+    "magContrastLevelRed",
+    "magContrastLevelGreen",
+    "magContrastLevelBlue",
     "magSmoothingMode",
     "magMouseTrackingMode",
+    "magControlTrackingMode",
+    "magTextTrackingMode",
+    "magEdgeMargin",
+    "magPointerFollowsFocus",
+    "magPointerFollowsZoomer",
+    "magColorFilteringMode",
     "magSourceDisplay",
     "magTargetDisplay",
     "verbalizePunctuationStyle",
@@ -239,7 +259,11 @@ httpServerPort          = 20433
 # The number of attempts to retry setting up an HTTP server
 # connection (each time incrementing the port number by 1).
 #
-maxHttpServerRetries   = 20
+maxHttpServerRetries    = 20
+
+# Whether or not recording is enabled via the HTTP server. 
+#
+enableRemoteLogging     = False
 
 # If True, enable speech.
 #
@@ -296,6 +320,12 @@ brailleRadioButtonIndicators = ["& y", "&=y"]
 #
 enableMagnifier                  = False
 
+# If True, changes made in the Magnifier pane will take place
+# immediately (i.e. without pressing the apply button).  Making
+# them permanent still requires pressing Apply or OK.
+#
+enableMagLiveUpdating            = True
+
 # If True, show the magnification cursor.
 #
 enableMagCursor                  = True
@@ -324,6 +354,20 @@ enableMagCrossHairClip           = False
 #
 magCrossHairSize                 = 16
 
+# Magnification cross-hair color value (hex color spec).
+#
+magCrossHairColor                   = '#000000'
+
+# Magnification Zoomer type.
+#
+MAG_ZOOMER_TYPE_FULL_SCREEN      = 0
+MAG_ZOOMER_TYPE_TOP_HALF         = 1
+MAG_ZOOMER_TYPE_BOTTOM_HALF      = 2
+MAG_ZOOMER_TYPE_LEFT_HALF        = 3
+MAG_ZOOMER_TYPE_RIGHT_HALF       = 4
+MAG_ZOOMER_TYPE_CUSTOM           = 5
+magZoomerType                    = MAG_ZOOMER_TYPE_FULL_SCREEN
+
 # Magnification zoomer region placement.
 #
 magZoomerLeft                    = screenWidth / 2
@@ -335,23 +379,95 @@ magZoomerBottom                  = screenHeight
 #
 magZoomFactor                    = 4.0
 
+# If True, display a border around the magnification zoomer region.
+#
+enableMagZoomerBorder           = False
+
+# The color and size of the border which separates the target
+# display from the source display.
+#
+magZoomerBorderSize              = 1
+magZoomerBorderColor             = '#000000'
+
 # If True, invert the magnification zoomer colors.
 #
 enableMagZoomerColorInversion    = False
 
+# The brightness levels.  The range is from -1 to 1, with 0
+# being "normal"/no change.
+#
+magBrightnessLevel               = 0
+magBrightnessLevelRed            = 0
+magBrightnessLevelGreen          = 0
+magBrightnessLevelBlue           = 0
+
+# The contrast levels.  The range is from -1 to 1, with 0
+# being "normal"/no change.
+#
+magContrastLevel                 = 0
+magContrastLevelRed              = 0
+magContrastLevelGreen            = 0
+magContrastLevelBlue             = 0
+
+# Magnification libcolorblind color filtering mode (see magColorFilteringMode).
+#
+MAG_COLOR_FILTERING_MODE_NONE                 = 0
+MAG_COLOR_FILTERING_MODE_SATURATE_RED         = 1
+MAG_COLOR_FILTERING_MODE_SATURATE_GREEN       = 2
+MAG_COLOR_FILTERING_MODE_SATURATE_BLUE        = 3
+MAG_COLOR_FILTERING_MODE_DESATURATE_RED       = 4
+MAG_COLOR_FILTERING_MODE_DESATURATE_GREEN     = 5
+MAG_COLOR_FILTERING_MODE_DESATURATE_BLUE      = 6
+MAG_COLOR_FILTERING_MODE_POSITIVE_HUE_SHIFT   = 7
+MAG_COLOR_FILTERING_MODE_NEGATIVE_HUE_SHIFT   = 8
+magColorFilteringMode = MAG_COLOR_FILTERING_MODE_NONE
+
 # Magnification smoothing mode (see magSmoothingMode).
 #
 MAG_SMOOTHING_MODE_BILINEAR      = 0
 MAG_SMOOTHING_MODE_NONE          = 1
 magSmoothingMode                 = MAG_SMOOTHING_MODE_BILINEAR
 
-# Magnification mouse tracking mode (see magMouseTrackingMode).
+# Magnification tracking mode styles (see magMouseTrackingMode,
+# magControlTrackingMode and magTextTrackingMode).
 #
-MAG_MOUSE_TRACKING_MODE_CENTERED     = 0
-MAG_MOUSE_TRACKING_MODE_NONE         = 1
-MAG_MOUSE_TRACKING_MODE_PROPORTIONAL = 2
-MAG_MOUSE_TRACKING_MODE_PUSH         = 3
-magMouseTrackingMode                 = MAG_MOUSE_TRACKING_MODE_CENTERED
+MAG_TRACKING_MODE_CENTERED     = 0
+MAG_TRACKING_MODE_PROPORTIONAL = 1
+MAG_TRACKING_MODE_PUSH         = 2
+MAG_TRACKING_MODE_NONE         = 3
+
+# To retain backward compatibility with previous versions of Orca.
+#
+MAG_MOUSE_TRACKING_MODE_CENTERED = MAG_TRACKING_MODE_CENTERED
+MAG_MOUSE_TRACKING_MODE_PROPORTIONAL = MAG_TRACKING_MODE_PROPORTIONAL
+MAG_MOUSE_TRACKING_MODE_PUSH = MAG_TRACKING_MODE_PUSH
+MAG_MOUSE_TRACKING_MODE_NONE = MAG_TRACKING_MODE_NONE
+
+# Magnification mouse tracking mode.
+#
+magMouseTrackingMode           = MAG_TRACKING_MODE_CENTERED
+
+# Magnification control and menu item tracking mode.
+#
+magControlTrackingMode         = MAG_TRACKING_MODE_PUSH
+
+# Magnification text cursor tracking mode.
+#
+magTextTrackingMode            = MAG_TRACKING_MODE_PUSH
+
+# Magnification edge margin (percentage of screen).
+#
+magEdgeMargin                  = 0
+
+# If enabled, automatically repositions the mouse pointer to the
+# menu item or control with focus.
+#
+magPointerFollowsFocus         = False
+
+# If enabled, automatically repositions the mouse pointer into the
+# zoomer if it's not visible when initially moved.
+#
+magPointerFollowsZoomer        = True
 
 # Magnification source display
 #
@@ -774,3 +890,18 @@ deprecatedMessages = False
 # maximize on caching.
 #
 focusHistoryLength = 5
+
+# Listen to all AT-SPI events, regardless to if we are using them or not.
+# This is useful for development and debugging.
+#
+listenAllEvents = False
+
+# This is a list of events that Orca should immidiately drop and never look at.
+#
+ignoredEventsList = ['object:bounds-changed']
+
+# Listen to Live Region events.  Tells Gecko.onChildrenChanged() and 
+# onTextInserted() event handlers to monitor these events for live region
+# changes.  
+#
+inferLiveRegions = True
