@@ -19,9 +19,9 @@
 
 """Speaks information about the current object of interest."""
 
-__id__        = "$Id: where_am_I.py 3234 2007-11-11 21:18:25Z joanied $"
-__version__   = "$Revision: 3234 $"
-__date__      = "$Date: 2007-11-11 16:18:25 -0500 (Sun, 11 Nov 2007) $"
+__id__        = "$Id: where_am_I.py 3378 2007-12-14 20:20:12Z wwalker $"
+__version__   = "$Revision: 3378 $"
+__date__      = "$Date: 2007-12-14 15:20:12 -0500 (Fri, 14 Dec 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -70,7 +70,7 @@ class WhereAmI:
            \n  label=%s \
            \n  name=%s \
            \n  role=%s \
-           \n  mnemonics=%s \
+           \n  keybinding=%s \
            \n  parent label= %s \
            \n  parent name=%s \
            \n  parent role=%s \
@@ -79,7 +79,7 @@ class WhereAmI:
             (self._getObjLabel(obj),
              self._getObjName(obj),
              obj.getRoleName(),
-             self._script.getAcceleratorAndShortcut(obj),
+             self._script.getKeyBinding(obj),
              self._getObjLabel(obj.parent),
              self._getObjName(obj.parent),
              obj.parent.getRoleName(),
@@ -90,8 +90,14 @@ class WhereAmI:
 
         if titleOrStatus:
             self._speakTitleOrStatus(obj, doubleClick)
+            return True
 
-        elif role == pyatspi.ROLE_CHECK_BOX:
+        else:
+            toolbar = self._getToolbar(obj)
+            if toolbar:
+                self._speakToolbar(toolbar)
+
+        if role == pyatspi.ROLE_CHECK_BOX:
             self._speakCheckBox(obj, doubleClick)
 
         elif role == pyatspi.ROLE_RADIO_BUTTON:
@@ -137,9 +143,15 @@ class WhereAmI:
         elif role == pyatspi.ROLE_LINK:
             self._speakLink(obj, doubleClick)
 
+        elif role == pyatspi.ROLE_TOGGLE_BUTTON:
+            self._speakToggleButton(obj, doubleClick)
+
         else:
             self._speakGenericObject(obj, doubleClick)
 
+        if not doubleClick:
+            self._speakObjDescription(obj)
+
         return True
 
     def _speakCheckBox(self, obj, doubleClick):
@@ -148,27 +160,17 @@ class WhereAmI:
         1. label
         2. role
         3. state
-        4. mnemonic (i.e. Alt plus the underlined letter), if any
+        4. accelerator (i.e. Alt plus the underlined letter), if any
         """
 
         utterances = []
-        text = self._getObjLabelAndName(obj) + " " + \
+        text = self.getObjLabelAndName(obj) + " " + \
                rolenames.getSpeechForRoleName(obj)
+        text = text + " " + self._getCheckBoxState(obj)
         utterances.append(text)
 
-        state = obj.getState()
-        if state.contains(pyatspi.STATE_CHECKED):
-            # Translators: this represents the state of a checkbox.
-            #
-            text = _("checked")
-        else:
-            # Translators: this represents the state of a checkbox.
-            #
-            text = _("not checked")
-        utterances.append(text)
-
-        text = self._getObjMnemonic(obj)
-        utterances.append(text)
+        accelerator = self._getObjAccelerator(obj)
+        utterances.append(accelerator)
 
         debug.println(self._debugLevel, "check box utterances=%s" \
                       % utterances)
@@ -183,14 +185,14 @@ class WhereAmI:
         3. role
         4. state
         5. relative position
-        6. mnemonic (i.e. Alt plus the underlined letter), if any
+        6. accelerator (i.e. Alt plus the underlined letter), if any
         """
 
         utterances = []
         text = self._getGroupLabel(obj)
         utterances.append(text)
 
-        text = self._getObjLabelAndName(obj) + " " + \
+        text = self.getObjLabelAndName(obj) + " " + \
                rolenames.getSpeechForRoleName(obj)
         utterances.append(text)
 
@@ -215,7 +217,7 @@ class WhereAmI:
         text = self._getPositionInGroup(obj)
         utterances.append(text)
 
-        text = self._getObjMnemonic(obj)
+        text = self._getObjAccelerator(obj)
         utterances.append(text)
 
         debug.println(self._debugLevel, "radio button utterances=%s" % \
@@ -230,7 +232,7 @@ class WhereAmI:
         2. role
         3. current value
         4. relative position
-        5. mnemonic (i.e. Alt plus the underlined letter), if any
+        5. accelerator (i.e. Alt plus the underlined letter), if any
         """
 
         utterances = []
@@ -247,8 +249,8 @@ class WhereAmI:
         text = self._getPositionInList(obj[0], name)
         utterances.append(text)
 
-        text = self._getObjMnemonic(obj)
-        utterances.append(text)
+        accelerator = self._getObjAccelerator(obj)
+        utterances.append(accelerator)
 
         debug.println(self._debugLevel, "combo box utterances=%s" % \
                       utterances)
@@ -261,7 +263,7 @@ class WhereAmI:
         1. label
         2. role
         3. current value
-        4. mnemonic (i.e. Alt plus the underlined letter), if any
+        4. accelerator (i.e. Alt plus the underlined letter), if any
         """
 
         utterances = []
@@ -274,7 +276,7 @@ class WhereAmI:
         name = self._getObjName(obj)
         utterances.append(name)
         
-        text = self._getObjMnemonic(obj)
+        text = self._getObjAccelerator(obj)
         utterances.append(text)
 
         debug.println(self._debugLevel, "spin button utterances=%s" % \
@@ -287,17 +289,17 @@ class WhereAmI:
 
         1. label
         2. role
-        3. mnemonic (i.e. Alt plus the underlined letter), if any
+        3. accelerator (i.e. Alt plus the underlined letter), if any
         """
 
         utterances = []
-        text = self._getObjLabelAndName(obj)
+        text = self.getObjLabelAndName(obj)
         utterances.append(text)
 
         text = rolenames.getSpeechForRoleName(obj)
         utterances.append(text)
 
-        text = self._getObjMnemonic(obj)
+        text = self._getObjAccelerator(obj)
         utterances.append(text)
 
         debug.println(self._debugLevel, "push button utterances=%s" % \
@@ -312,7 +314,7 @@ class WhereAmI:
         2. role
         3. value
         4. percentage (if possible)
-        5. mnemonic (i.e. Alt plus the underlined letter), if any
+        5. accelerator (i.e. Alt plus the underlined letter), if any
         """
 
         utterances = []
@@ -328,7 +330,7 @@ class WhereAmI:
         #
         utterances.append(_("%s percent") % values[1])
 
-        text = self._getObjMnemonic(obj)
+        text = self._getObjAccelerator(obj)
         utterances.append(text)
 
         debug.println(self._debugLevel, "slider utterances=%s" % \
@@ -342,17 +344,17 @@ class WhereAmI:
 
         1. Name of the menu containing the item, followed by its role
         2. item name, followed by its role (if a menu) followed by its
-        accelerator key, if any
+        accelerator key binding, if any
         3. relative position
-        4. mnemonic (i.e. Alt plus the underlined letter), if any
+        4. mnemonic (i.e. the underlined letter), if any
         """
 
         utterances = []
-        text = self._getObjLabelAndName(obj.parent) + " " + \
+        text = self.getObjLabelAndName(obj.parent) + " " + \
                rolenames.getSpeechForRoleName(obj.parent)
-        utterances.append(text)
+        utterances.append(text.strip())
 
-        text = self._getObjLabelAndName(obj)
+        text = self.getObjLabelAndName(obj)
         utterances.append(text)
 
         state = obj.getState()
@@ -362,7 +364,11 @@ class WhereAmI:
             utterances.append(text)
 
         if obj.getRole() == pyatspi.ROLE_CHECK_MENU_ITEM:
-            if state.contains(pyatspi.STATE_CHECKED):
+            if state.contains(pyatspi.STATE_INDETERMINATE):
+                # Translators: this represents the state of a checkbox.
+                #
+                text = _("partially checked")
+            elif state.contains(pyatspi.STATE_CHECKED):
                 # Translators: this represents the state of a checkbox.
                 #
                 text = _("checked")
@@ -385,23 +391,18 @@ class WhereAmI:
                 text = _("not selected")
             utterances.append(text)
 
-        text = self._getObjAccelerator(obj)
+        text = self._getObjAccelerator(obj, False, False)
         utterances.append(text)
 
         name = self._getObjName(obj)
         text = self._getPositionInList(obj.parent, name)
         utterances.append(text)
 
-        text = self._getObjShortcut(obj)
-
-        # The object's shortcut will be the full list of keys (e.g.
-        # Alt FO for the open menu item in the File menu). We only
-        # want to speak the shortcut associated with the menu item.
-        #
-        if text and obj.parent and obj.parent.getRole() == pyatspi.ROLE_MENU:
-            text = text[-1]
-        
-        utterances.append(text)
+        if obj.parent \
+           and obj.parent.getRole() in [pyatspi.ROLE_MENU, 
+                                        pyatspi.ROLE_MENU_BAR]:
+            text = self._getObjMnemonic(obj)
+            utterances.append(text)
 
         debug.println(self._debugLevel, "menu item utterances=%s" % \
                       utterances)
@@ -414,7 +415,7 @@ class WhereAmI:
         1. role
         2. label + 'page'
         3. relative position
-        4. mnemonic (i.e. Alt plus the underlined letter), if any
+        4. accelerator (i.e. Alt plus the underlined letter), if any
         """
 
         utterances = []
@@ -423,14 +424,14 @@ class WhereAmI:
 
         # Translators: "page" is the word for a page tab in a tab list.
         #
-        text = _("%s page") % self._getObjLabelAndName(obj)
+        text = _("%s page") % self.getObjLabelAndName(obj)
         utterances.append(text)
 
         name = self._getObjName(obj)
         text = self._getPositionInList(obj.parent, name)
         utterances.append(text)
 
-        text = self._getObjMnemonic(obj)
+        text = self._getObjAccelerator(obj)
         utterances.append(text)
 
         debug.println(self._debugLevel, "page utterances=%s" % \
@@ -449,7 +450,7 @@ class WhereAmI:
             attibute information before  (bold "text")
             by 'selected' (single press)
             C. if the current line is blank/empty, 'blank'
-        4. mnemonic (i.e. Alt plus the underlined letter), if any
+        4. accelerator (i.e. Alt plus the underlined letter), if any
 
         Gaim, gedit, OpenOffice Writer and Terminal
         """
@@ -490,7 +491,7 @@ class WhereAmI:
             text = Q_("text|selected")
             utterances.append(text)
 
-        text = self._getObjMnemonic(obj)
+        text = self._getObjAccelerator(obj)
         utterances.append(text)
 
         debug.println(self._debugLevel, "text utterances=%s" % \
@@ -603,7 +604,8 @@ class WhereAmI:
         utterances = []
 
         text = self._getObjLabel(obj)
-        utterances.append(text)
+        if text:
+            utterances.append(text)
 
         text = rolenames.getSpeechForRoleName(obj)
         utterances.append(text)
@@ -652,7 +654,6 @@ class WhereAmI:
     def _speakParagraph(self, obj, doubleClick):
         """Speak a paragraph object.
         """
-
         self._speakText(obj, doubleClick)
 
     def _speakIconPanel(self, obj, doubleClick):
@@ -669,16 +670,18 @@ class WhereAmI:
         childCount = panel.childCount
 
         utterances.append(_("Icon panel"))
-        utterances.append(self._getObjLabelAndName(obj))
-        utterances.append(rolenames.getSpeechForRoleName(obj))
+        utterances.append(self.getObjLabelAndName(obj))
 
         selectedItems = []
         totalSelectedItems = 0
+        currentItem = 0
         for child in panel:
             state = child.getState()
             if state.contains(pyatspi.STATE_SELECTED):
                 totalSelectedItems += 1
                 selectedItems.append(child)
+            if state.contains(pyatspi.STATE_FOCUSED):
+                currentItem = child.getIndexInParent() + 1
 
         # Translators: this is a count of the number of selected icons 
         # and the count of the total number of icons within an icon panel. 
@@ -690,9 +693,16 @@ class WhereAmI:
                               (totalSelectedItems, childCount)
         utterances.append(itemString)
 
+        # Translators: this is a indication of the focused icon and the
+        # count of the total number of icons within an icon panel. An
+        # example of an icon panel is the Nautilus folder view.
+        #
+        itemString = _("on item %d of %d") % (currentItem, childCount)
+        utterances.append(itemString)
+
         if doubleClick:
             for i in range(0, len(selectedItems)):
-                utterances.append(self._getObjLabelAndName(selectedItems[i]))
+                utterances.append(self.getObjLabelAndName(selectedItems[i]))
 
         speech.speakUtterances(utterances)
         
@@ -761,11 +771,37 @@ class WhereAmI:
                     domainoutput = _('different site')
 
         speech.speakUtterances([linkoutput, domainoutput, sizeoutput])
+
+    def _speakToggleButton(self, obj, doubleClick):
+        """Speak toggle button information:
+           1. Name/Label
+           2. Role
+           3. State (pressed/not pressed)
+        """
+
+        utterances = []
+        text = self.getObjLabelAndName(obj)
+        utterances.append(text)
+
+        text = rolenames.getSpeechForRoleName(obj)
+        utterances.append(text)
+
+        if obj.getState().contains(pyatspi.STATE_CHECKED):
+            # Translators: the state of a toggle button.
+            #
+            checkedState = _("pressed")
+        else:
+            # Translators: the state of a toggle button.
+            #
+            checkedState = _("not pressed")
+        utterances.append(checkedState)
+
+        speech.speakUtterances(utterances)
       
     def __extractSize(self, uri):
-        '''
-        Get the http header for a given uri and try to extract the size (Content-length).
-        '''
+        """Get the http header for a given uri and try to extract the size
+        (Content-length).
+        """
         try:
             x = urllib2.urlopen(uri)
             try:
@@ -776,9 +812,9 @@ class WhereAmI:
             return None
   
     def __formatSizeOutput(self, sizestr):
-        '''
-        Format the size output announcement.  Changes wording based on size.
-        '''
+        """Format the size output announcement.  Changes wording based on
+        size.
+        """
         # sanity check
         if sizestr is None or sizestr == '':
             return ''
@@ -802,7 +838,7 @@ class WhereAmI:
         """
 
         utterances = []
-        text = self._getObjLabelAndName(obj)
+        text = self.getObjLabelAndName(obj)
         utterances.append(text)
 
         text = rolenames.getSpeechForRoleName(obj)
@@ -838,7 +874,7 @@ class WhereAmI:
 
         return text
 
-    def _getObjLabelAndName(self, obj):
+    def getObjLabelAndName(self, obj):
         """Returns the object label plus the object name.
         """
 
@@ -877,13 +913,13 @@ class WhereAmI:
                 break
 
         if labelledBy:
-            text = self._getObjLabelAndName(labelledBy)
+            text = self.getObjLabelAndName(labelledBy)
         else:
             parent = obj.parent
             while parent and (parent.parent != parent):
                 if parent.getRole() in [pyatspi.ROLE_PANEL,
                                         pyatspi.ROLE_FILLER]:
-                    label = self._getObjLabelAndName(parent)
+                    label = self.getObjLabelAndName(parent)
                     if label and label != "":
                         text = label
                         break
@@ -960,44 +996,36 @@ class WhereAmI:
 
         return text
 
-    def _getObjMnemonic(self, obj):
-        """Returns the accellerator and/or shortcut for the object,
-        if either exists.
-        """
-
-        results = self._script.getAcceleratorAndShortcut(obj)
-
-        text = ""
-        if not results[1]:
-            text = results[0]
-        else:
-            text = results[0] + " " +  results[1]
-
-        return text
-
-    def _getObjAccelerator(self, obj):
+    def _getObjAccelerator(self,
+                           obj, 
+                           fallbackToMnemonic=True,
+                           fallbackToFullPath=True):
         """Returns the accelerator for the object, if it exists.
         """
 
-        results = self._script.getAcceleratorAndShortcut(obj)
+        # We'll try the real accelerator first, but fallback to the
+        # mnemonic if there is no accelerator.  This is done because
+        # some implementations, such as the Java platform, will
+        # only give us the mnemonic sometimes.
+        #
+        results = self._script.getKeyBinding(obj)
+        if results[2]:
+            return results[2]
 
-        text = ""
-        if results[0]:
-            text = results[0]
+        mnemonic = results[0]
+        if mnemonic and fallbackToMnemonic:
+            return mnemonic
 
-        return text
+        if fallbackToFullPath:
+            return results[1]
 
-    def _getObjShortcut(self, obj):
-        """Returns the shortcut for the object, if it exists.
+        return ""
+
+    def _getObjMnemonic(self, obj):
+        """Returns the mnemonic (a letter) for the object, if it exists.
         """
-
-        results = self._script.getAcceleratorAndShortcut(obj)
-
-        text = ""
-        if results[1]:
-            text = results[1]
-
-        return text
+        results = self._script.getKeyBinding(obj)
+        return results[0][-1:]
 
     def _getSliderValues(self, obj):
         """Returns the slider's current value and percentage.
@@ -1050,8 +1078,7 @@ class WhereAmI:
         """Get the speech utterances for a single table cell.
         """
 
-        # Don't speak check box cells that area not checked.
-        notChecked = False
+        isToggle = False
         try:
             action = obj.queryAction()
         except NotImplementedError:
@@ -1059,21 +1086,54 @@ class WhereAmI:
         else:
             for i in range(0, action.nActions):
                 if action.getName(i) == "toggle":
-                    state = obj.getState()
-                    if not state.contains(pyatspi.STATE_CHECKED):
-                        notChecked = True
+                    isToggle = True
                     break
 
-        if notChecked:
-            return ""
-
-        descendant = self._script.getRealActiveDescendant(obj)
-        text = self._script.getDisplayedText(descendant)
+        if isToggle:
+            text = rolenames.getSpeechForRoleName(obj, pyatspi.ROLE_CHECK_BOX)
+            text = text + " " + self._getCheckBoxState(obj)
+        else:
+            descendant = self._script.getRealActiveDescendant(obj)
+            text = self._script.getDisplayedText(descendant)
 
         debug.println(self._debugLevel, "cell=<%s>" % text)
 
         return text
 
+    def _getCheckBoxState(self, obj):
+        """Get the state of a checkbox/toggle-able table cell.
+        """
+
+        isToggle = (obj.getRole() == pyatspi.ROLE_CHECK_BOX)
+        if not isToggle:
+            try:
+                action = obj.queryAction()
+            except NotImplementedError:
+                pass
+            else:
+                for i in range(0, action.nActions):
+                    if action.getName(i) == "toggle":
+                        isToggle = True
+                        break
+        if not isToggle:
+            return ""
+
+        state = obj.getState()
+        if state.contains(pyatspi.STATE_INDETERMINATE):
+            # Translators: this represents the state of a checkbox.
+            #
+            text = _("partially checked")
+        elif state.contains(pyatspi.STATE_CHECKED):
+            # Translators: this represents the state of a checkbox.
+            #
+            text = _("checked")
+        else:
+            # Translators: this represents the state of a checkbox.
+            #
+            text = _("not checked")
+
+        return text
+
     def _getTextSelection(self, obj):
         """Get the text selection for the given object.
 
@@ -1104,7 +1164,7 @@ class WhereAmI:
 
         return [textContents, startOffset, endOffset]
 
-    def _getTextSelections(self, obj, doubleClick):
+    def getTextSelections(self, obj, doubleClick):
         """Get all the text applicable text selections for the given object.
         If the user doubleclicked, look to see if there are any previous 
         or next text objects that also have selected text and add in their 
@@ -1171,6 +1231,18 @@ class WhereAmI:
                                 morePossibleSelections = True
                         break
 
+        else:
+            # We're only interested in the text selected on this line.
+            #
+            [line, lineStart, lineEnd] = \
+                   text.getTextAtOffset(text.caretOffset,
+                                        pyatspi.TEXT_BOUNDARY_LINE_START)
+            if lineStart != endOffset:
+                startOffset = max(startOffset, lineStart)
+                endOffset = min(endOffset, lineEnd)
+                textContents = line[startOffset - lineStart:
+                                    endOffset - lineStart]
+
         return [textContents, startOffset, endOffset]
 
     def _hasTextSelections(self, obj):
@@ -1260,7 +1332,7 @@ class WhereAmI:
            (not doubleClick and current):
             selected = True
             [textContents, startOffset, endOffset] = \
-                                  self._getTextSelections(obj, doubleClick)
+                                  self.getTextSelections(obj, doubleClick)
         else:
             # Get the line containing the caret
             #
@@ -1365,7 +1437,7 @@ class WhereAmI:
         else:
             return ""
 
-    def _stringToDictionary(self, str):
+    def _stringToDictionary(self, tokenString):
         """Converts a string of text attribute tokens of the form
         <key>:<value>; into a dictionary of keys and values.
         Text before the colon is the key and text afterwards is the
@@ -1373,33 +1445,16 @@ class WhereAmI:
         """
 
         dictionary = {}
-        allTokens = str.split(";")
+        allTokens = tokenString.split(";")
         for token in allTokens:
             item = token.split(":")
             if len(item) == 2:
-                item[0] = self._removeLeadingSpaces(item[0])
-                item[1] = self._removeLeadingSpaces(item[1])
+                item[0] = item[0].lstrip()
+                item[1] = item[1].lstrip()
                 dictionary[item[0]] = item[1]
 
         return dictionary
 
-    def _removeLeadingSpaces(self, str):
-        """Returns a string with the leading space characters removed.
-        """
-
-        newStr = ""
-        leadingSpaces = True
-        for i in range(0, len(str)):
-            if str[i] == " ":
-                if leadingSpaces:
-                    continue
-            else:
-                leadingSpaces = False
-
-            newStr += str[i]
-
-        return newStr
-
     def _speakTitleOrStatus(self, obj, doubleClick):
         """When pressed a single time, Orca will speak the following
         information:
@@ -1428,10 +1483,10 @@ class WhereAmI:
                 self._speakDefaultButton(window)
         else:
             if results[0]:
-                text = self._getObjLabelAndName(results[0])
+                text = self.getObjLabelAndName(results[0])
                 utterances.append(text)
             if results[1]:
-                text = self._getObjLabelAndName(results[1])
+                text = self.getObjLabelAndName(results[1])
                 utterances.append(text)
 
             debug.println(self._debugLevel, "titlebar utterances=%s" % \
@@ -1449,7 +1504,7 @@ class WhereAmI:
         while parent and (parent.parent != parent):
             #debug.println(self._debugLevel,
             #              "_getFrameAndDialog: parent=%s, %s" % \
-            #              (parent.getRole(), self._getObjLabelAndName(parent)))
+            #              (parent.getRole(), self.getObjLabelAndName(parent)))
             if parent.getRole() == pyatspi.ROLE_FRAME:
                 results[0] = parent
             if parent.getRole() in [pyatspi.ROLE_DIALOG,
@@ -1466,7 +1521,7 @@ class WhereAmI:
             return
 
         # debug.println(self._debugLevel, "_findStatusBar: ROOT=%s, %s" % \
-        #               (obj.getRole(), self._getObjLabelAndName(obj)))
+        #               (obj.getRole(), self.getObjLabelAndName(obj)))
         state = obj.getState()
         managesDescendants = state.contains(pyatspi.STATE_MANAGES_DESCENDANTS)
         if managesDescendants:
@@ -1475,7 +1530,7 @@ class WhereAmI:
         for child in obj:
             # debug.println(self._debugLevel,
             #               "_findStatusBar: child=%s, %s" % \
-            #               (child.getRole(), self._getObjLabelAndName(child)))
+            #               (child.getRole(), self.getObjLabelAndName(child)))
             if child.getRole() == pyatspi.ROLE_STATUS_BAR:
                 self._statusBar = child
                 return
@@ -1515,7 +1570,7 @@ class WhereAmI:
         for child in obj:
             # debug.println(self._debugLevel,
             #               "_getDefaultButton: child=%s, %s" % \
-            #               (child.getRole(), self._getObjLabelAndName(child)))
+            #               (child.getRole(), self.getObjLabelAndName(child)))
             state = child.getState()
             if child.getRole() == pyatspi.ROLE_PUSH_BUTTON \
                 and state.contains(pyatspi.STATE_IS_DEFAULT):
@@ -1557,3 +1612,41 @@ class WhereAmI:
         debug.println(self._debugLevel, "default button utterances=%s" % \
                       utterances)
         speech.speakUtterances(utterances)
+
+    def _speakObjDescription(self, obj):
+        """Speaks the object's description if it is not the same as
+        the object's name or label.
+        """
+
+        description = obj.description
+        name = self._getObjName(obj)
+        label = self._getObjLabel(obj)
+
+        if description and not description in [name, label]:
+            speech.speak(description)
+
+    def _getToolbar(self, obj):
+        """Returns the toolbar containing the object or None if the object
+        is not contained in a toolbar.
+        """
+
+        parent = obj.parent
+        while parent and (parent.parent != parent):
+            if parent.getRole() == pyatspi.ROLE_TOOL_BAR:
+                return parent
+            parent = parent.parent
+
+        return None
+
+    def _speakToolbar(self, obj):
+        """Speaks the label and/or name of a toolbar, followed by its role.
+        """
+
+        utterances = []
+        text = self.getObjLabelAndName(obj) + " " + \
+               rolenames.getSpeechForRoleName(obj)
+        utterances.append(text.strip())
+
+        debug.println(self._debugLevel, "toolbar utterances=%s" \
+                      % utterances)
+        speech.speakUtterances(utterances)
